==> nextcloud-app-spreed-1%3A6.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/da.js <==
OC.L10N.register(
    "spreed",
    {
    "{name} (public)" : "{name} (offentlig)",
    "New conversation …" : "Ny samtale …",
    "Participants" : "Deltagere",
    "Chat" : "Chat",
    "Talk" : "Snak",
    "Exit fullscreen (f)" : "Forlad fuldskærmsvisning (f)",
    "Fullscreen (f)" : "Vis i fuldskærm (f)",
    "Copy" : "Kopiér",
    "Copied!" : "Kopieret!",
    "Not supported!" : "Ikke understøttet",
    "Press ⌘-C to copy." : "Tryk ⌘-C for at kopiere.",
    "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
    "Start a conversation" : "Start en samtale",
    "Share" : "Del",
    "Request password" : "Anmod om adgangskode",
    "Please enter the password for this call" : "Indtast venligst password for dette opkald",
    "Password required" : "Password påkrævet",
    "Password" : "Password",
    "Cancel" : "Annullér",
    "Submit" : "Indsend",
    "Leave call" : "Forlad opkald",
    "Join call" : "Deltag i opkaldet",
    "Start call" : "Start opkald",
    "Go to file" : "Gå til fil",
    "Share link" : "Del link",
    "Change password" : "Skift password",
    "Set password" : "Sæt password",
    "Name" : "Navn",
    "Conversation name" : "Samtalenavn",
    "Rename" : "Omdøb",
    "Copy link" : "Kopier link",
    "Conversation with {name}" : "Samtale med {name}",
    "Link copied!" : "Link kopieret!",
    "You" : "Dig",
    "No messages yet, start the conversation!" : "Ingen beskeder endnu, start samtalen!",
    "New message …" : "Ny besked …",
    "Send" : "Send",
    "Guest" : "Gæst",
    "[Unknown user name]" : "[Ukendt brugernavn] ",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "Der opstod fejl under indsendelse af besked",
    "File to share" : "Vælg fil til deling",
    "Edit" : "Rediger",
    "Join a conversation or start a new one" : "Deltag i en samtale eller start en ny",
    "Say hi to your friends and colleagues!" : "Sig hej til dine venner og kollegaer.",
    "No other people in this call" : "Ingen andre deltager i dette opkald",
    "Waiting for {participantName} to join the call …" : "Venter på {participantName} tilslutter sig opkaldet ...",
    "Waiting for others to join the call …" : "Venter på andre tilslutter sig opkaldet ...",
    "Share this link to invite others!" : "Del dette link for at invitere andre!",
    "WebRTC is not supported in your browser :-/" : "WebRTC er ikke undertøttet i din browser :-/",
    "Please use a different browser like Firefox or Chrome" : "Benyt venligst en anden browser f.eks. Firefox eller Chrome",
    "Waiting for camera and microphone permissions" : "Venter på kamera og mikrofon tilladelser",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "For at give bruge denne app skal du give din browser adgang til dit kamera og mikrofon.",
    "This conversation has ended" : "Samtalen er slut",
    "Mute audio" : "Slå lyden fra",
    "Disable video" : "Deaktiver video",
    "Share screen" : "Del skærm",
    "Share whole screen" : "Del hele skærmen",
    "Share a single window" : "Del et vindue",
    "Show your screen" : "Vis din skærm",
    "Stop screensharing" : "Stop skærmdeling",
    "Mute audio (m)" : "Slå lyden fra (m)",
    "Unmute audio (m)" : "Slå lyden til (m)",
    "No audio" : "Ingen lyd",
    "Disable video (v)" : "Slå video fra (v)",
    "Enable video (v)" : "Slå video til (v)",
    "No Camera" : "Intet kamera",
    "Screensharing is not supported by your browser." : "Skærmdeling er ikke understøttet af din browser.",
    "Screensharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden bliver vist gennem HTTPS.",
    "Screensharing options" : "Skærmdeling indstillinger",
    "Sharing your screen only works with Firefox version 52 or newer." : "Skærmdeling virker kun med Firefox version 52 eller nyere.",
    "Screensharing extension is required to share your screen." : "En skærmdeling udvidelse er påkrævet for at dele din skærm.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Brug venligst en anden browser som Firefox og Chrome for at dele din skærm.",
    "An error occurred while starting screensharing." : "Der opstod en fejl da du prøvede at dele skærm.",
    "Enable screensharing" : "Slå skærmdeling til",
    "moderator" : "moderator",
    "Demote from moderator" : "Degrader fra moderator",
    "Promote to moderator" : "Forfrem til moderator",
    "Remove participant" : "Fjern deltager",
    "Add participant …" : "Tilføj deltager…",
    "Favorited" : "Tilføjet til favoritter",
    "Remove from favorites" : "Fjernet fra favoritter",
    "Add to favorites" : "Føj til favoritter",
    "Leave conversation" : "Forlad samtale",
    "Delete conversation" : "Slet samtale",
    "Your screen" : "Din skærm",
    "{participantName}'s screen" : "{participantName}s skærm",
    "Guest's screen" : "Gæsts skærm",
    "Close" : "Luk",
    "Show screen" : "Vis skærm",
    "Enable video" : "Slå video til",
    "Access to microphone & camera is only possible with HTTPS" : "Adgang til mikrofon og kamera er kun tilgængeligt over HTTPS",
    "Access to microphone & camera was denied" : "Ingen adgang til mikrofon og kamera",
    "WebRTC is not supported in your browser" : "WebRTC er ikke undertøttet i din browser",
    "Error while accessing microphone & camera" : "Der opstod en fejl da vi prøvede at få adgang til din mikrofon og kamera",
    "a conversation" : "en samtale",
    "(Duration %s)" : "(Varighed %s)",
    "You attended a call with {user1}" : "Du deltog i et opkald med {user1}",
    "_%n guest_::_%n guests_" : ["%n gæst","%n gæster"],
    "You attended a call with {user1} and {user2}" : "Du deltog i et opkald med {user1} og {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Du deltog i et opkald med {user1}, {user2} og {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Du deltog i et opkald med {user1}, {user2}, {user3} og {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du deltog i et opkald med {user1}, {user2}, {user3}, {user4} og {user5}",
    "_%n other_::_%n others_" : ["%n andre","%n andre"],
    "{actor} invited you to {call}" : "{actor} inviterede dig til {call}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Du var inviteret til et <strong>snakke</strong> rum eller fik et <strong>opkald</strong>",
    "{actor} created the conversation" : "{actor} oprettede samtalen",
    "You created the conversation" : "Du oprettede samtalen",
    "{actor} started a call" : "{actor} startede et opkald",
    "You started a call" : "Du startede et opkald",
    "{actor} joined the call" : "{actor} deltog i opkaldet",
    "You joined the call" : "Du forbandt til opkaldet",
    "{actor} left the call" : "{actor} forlod opkaldet",
    "You left the call" : "Du forlod opkaldet",
    "{actor} allowed guests" : "{actor} tillod gæster",
    "You allowed guests" : "Du tillod gæster",
    "{actor} disallowed guests" : "{actor} forbød gæster",
    "You disallowed guests" : "Du forbød gæster",
    "{actor} set a password" : "{actor} indstillede en adgangskode",
    "You set a password" : "Du indstillede en adgangskode",
    "{actor} removed the password" : "{actor} fjernede adgangskoden",
    "You removed the password" : "Du fjernede adgangskoden",
    "{actor} added {user}" : "{actor} tilføjede {user}",
    "You joined the conversation" : "Du forbandt til samtalen",
    "{actor} joined the conversation" : "{actor} forbandt til samtalen",
    "You added {user}" : "Du tilføjede {user}",
    "{actor} added you" : "{actor} tilføjede dig",
    "You left the conversation" : "Du forlod samtalen",
    "{actor} left the conversation" : "{actor} forlod samtalen",
    "{actor} removed {user}" : "{actor} fjernede {user}",
    "You removed {user}" : "Du fjernede {user}",
    "{actor} removed you" : "{actor} fjernede dig",
    "{actor} promoted {user} to moderator" : "{actor} forfremmede {user} til moderator",
    "You promoted {user} to moderator" : "Du forfremmede {user} til moderator",
    "{actor} promoted you to moderator" : "{actor} forfremmede dig til moderator",
    "{actor} demoted {user} from moderator" : "{actor} degraderede {user} fra moderator",
    "You demoted {user} from moderator" : "Du degraderede {user} fra moderator",
    "{actor} demoted you from moderator" : "{actor} degraderede dig fra moderator",
    "{actor} shared a file which is no longer available" : "{actor} delte en fil, der ikke længere er tilgængelig",
    "You shared a file which is no longer available" : "Du delte en fil, der ikke længere er tilgængelig",
    "%s (guest)" : "%s (gæst)",
    "Call with {user1} and {user2} (Duration {duration})" : "Opkald med {user1} og {user2} (Varighed {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Opkald med {user1}, {user2} og {user3} (Varighed {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Opkald med {user1}, {user2}, {user3} og {user4} (Varighed {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Opkald med {user1}, {user2}, {user3}, {user4} og {user5} (Varighed {duration})",
    "Talk to %s" : "Tal med %s",
    "File is not shared, or shared but not with the user" : "Filen er ikke delt, eller den er delt men ikke med brugeren",
    "You were invited to a conversation." : "Du blev inviteret til en samtale.",
    "Conversation invitation" : "Invitation til samtale",
    "Click the button below to join." : "Tryk på knappen nedenfor for at deltage.",
    "Join »%s«" : "Deltag i »%s«",
    "{user} sent you a private message" : "{user} sendte dig en privat besked",
    "{user} sent a message in conversation {call}" : "{user} sendte en besked i samtalen {call}",
    "A deleted user sent a message in conversation {call}" : "En slettet bruger sendte en besked i samtalen {call}",
    "A guest sent a message in conversation {call}" : "En gæst sendte en besked i samtalen {call}",
    "{user} mentioned you in a private conversation" : "{user} omtalte dig i en privat samtale",
    "{user} mentioned you in conversation {call}" : "{user} omtalte dig i samtalen {call}",
    "A deleted user mentioned you in conversation {call}" : "En slettet bruger omtalte dig i samtalen {call}",
    "A guest mentioned you in conversation {call}" : "En gæst omtalte dig i samtalen {call}",
    "{user} invited you to a private conversation" : "{user} inviterede dig til en privat samtale",
    "{user} invited you to a group conversation: {call}" : "{user} inviterede dig til en gruppesamtale: {call}",
    "{user} wants to talk with you" : "{user} vil gerne snakke med dig",
    "A group call has started in {call}" : "Et gruppeopkald er startet i {call}",
    "TURN server URL" : "TURN server URL",
    "Validate SSL certificate" : "Godkend SSL certifikat",
    "STUN server URL" : "STUN server URL",
    "TURN server protocols" : "TURN server protokoller ",
    "UDP and TCP" : "UDP og TCP",
    "UDP only" : "kun UDP",
    "TCP only" : "kun TCP",
    "Saved" : "Gemt",
    "Shared secret" : "Delt hemmelighed",
    "STUN servers" : "STUN servere",
    "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN server bliver brugt til at bestemme den offentlige IP adresse for deltagerne bagved en router.",
    "The password is wrong. Try again." : "Passwordet er forkert. Prøv igen.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signaleringsserver kan eventuelt bruges i større installationer. Efterlad tom for at bruge intern signaleringsserver.",
    "TURN server" : "TURN server",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN serveren bliver brugt til at proxy trafikken fra deltagerne bagved en firewall.",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "Signaling server URL" : "Signalserver URL",
    "Delete server" : "Slet server",
    "Add new server" : "Tilføj ny server",
    "TURN server shared secret" : "TURN server delte hemmelighed",
    "Test server" : "Test server",
    "New public conversation" : "Ny offentlig samtale",
    "New group conversation" : "Ny gruppesamtale",
    "_%n other guest_::_%n other guests_" : ["%n anden gæst","%n andre gæster"],
    ", " : ", ",
    "%s mentioned you in a private conversation" : "%s omtalte dig i en privat samtale",
    "%s mentioned you in a group conversation: %s" : "%s omtalte dig i en gruppesamtale: %s",
    "{user} mentioned you in a group conversation: {call}" : "{user} omtalte dig i en gruppesamtale: {call}",
    "%s mentioned you in a group conversation" : "%s omtalte dig i en gruppesamtale",
    "{user} mentioned you in a group conversation" : "{user} omtalte dig i en gruppesamtale",
    "You were mentioned in a group conversation by a deleted user: %s" : "En slettet bruger omtalte dig i en gruppesamtale: %s",
    "You were mentioned in a group conversation by a deleted user: {call}" : "En slettet bruger omtalte dig i en gruppesamtale: {call}",
    "You were mentioned in a group conversation by a deleted user" : "En slettet bruger omtalte dig i en gruppesamtale",
    "A guest mentioned you in a group conversation: %s" : "En gæst omtalte dig i en gruppesamtale: %s",
    "A guest mentioned you in a group conversation: {call}" : "En gæst omtalte dig i en gruppesamtale: {call}",
    "A guest mentioned you in a group conversation" : "En gæst omtalte dig i en gruppesamtale",
    "%s invited you to a private conversation" : "%s inviterede dig til en privat samtale",
    "%s invited you to a group conversation: %s" : "%s inviterede dig til en gruppesamtale: %s",
    "%s invited you to a group conversation" : "%s inviterede dig til en gruppesamtale",
    "{user} invited you to a group conversation" : "{user} inviterede dig til en gruppesamtale",
    "A group call has started" : "Et gruppeopkald er startet",
    "This call is password-protected" : "Dette opkald er password beskyttet ",
    "Signaling server" : "Signalerer server",
    "Always notify" : "Giv altid besked",
    "Notify on @-mention" : "Giv besked ved @-omtale",
    "Never notify" : "Giv aldrig besked",
    "Join now" : "Deltag nu",
    "{user} sent a message in a conversation" : "{user} sendte en besked i en samtale",
    "A deleted user sent a message in a conversation" : "En slettet bruger sendte en besked i en samtale",
    "A guest sent a message in a conversation" : "En gæst sendte en besked i en samtale",
    "{user} mentioned you in a conversation" : "{user} omtalte dig i en samtale",
    "A deleted user mentioned you in a conversation" : "En slettet bruger omtalte dig i en samtale",
    "A guest mentioned you in a conversation" : "En gæst omtalte dig i en samtale"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A7.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/da.js <==
OC.L10N.register(
    "spreed",
    {
    "{name} (public)" : "{name} (offentlig)",
    "New conversation …" : "Ny samtale …",
    "Participants" : "Deltagere",
    "Chat" : "Chat",
    "Talk" : "Snak",
    "Exit fullscreen (f)" : "Forlad fuldskærmsvisning (f)",
    "Fullscreen (f)" : "Vis i fuldskærm (f)",
    "Copy" : "Kopiér",
    "Copied!" : "Kopieret!",
    "Not supported!" : "Ikke understøttet",
    "Press ⌘-C to copy." : "Tryk ⌘-C for at kopiere.",
    "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
    "Start a conversation" : "Start en samtale",
    "Share" : "Del",
    "Request password" : "Anmod om adgangskode",
    "Please enter the password for this call" : "Indtast venligst password for dette opkald",
    "Password required" : "Password påkrævet",
    "Password" : "Password",
    "Cancel" : "Annullér",
    "Submit" : "Indsend",
    "Leave call" : "Forlad opkald",
    "Join call" : "Deltag i opkaldet",
    "Start call" : "Start opkald",
    "Go to file" : "Gå til fil",
    "Share link" : "Del link",
    "Copy link" : "Kopier link",
    "Change password" : "Skift password",
    "Set password" : "Sæt password",
    "Name" : "Navn",
    "Conversation name" : "Samtalenavn",
    "Rename" : "Omdøb",
    "Link copied!" : "Link kopieret!",
    "Conversation with {name}" : "Samtale med {name}",
    "You" : "Dig",
    "Guest" : "Gæst",
    "No messages yet, start the conversation!" : "Ingen beskeder endnu, start samtalen!",
    "New message …" : "Ny besked …",
    "Send" : "Send",
    "[Unknown user name]" : "[Ukendt brugernavn] ",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "Der opstod fejl under indsendelse af besked",
    "File to share" : "Vælg fil til deling",
    "Edit" : "Rediger",
    "Join a conversation or start a new one" : "Deltag i en samtale eller start en ny",
    "Say hi to your friends and colleagues!" : "Sig hej til dine venner og kollegaer.",
    "No other people in this call" : "Ingen andre deltager i dette opkald",
    "Waiting for {participantName} to join the call …" : "Venter på {participantName} tilslutter sig opkaldet ...",
    "Waiting for others to join the call …" : "Venter på andre tilslutter sig opkaldet ...",
    "Share this link to invite others!" : "Del dette link for at invitere andre!",
    "WebRTC is not supported in your browser :-/" : "WebRTC er ikke undertøttet i din browser :-/",
    "Please use a different browser like Firefox or Chrome" : "Benyt venligst en anden browser f.eks. Firefox eller Chrome",
    "Waiting for camera and microphone permissions" : "Venter på kamera og mikrofon tilladelser",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "For at give bruge denne app skal du give din browser adgang til dit kamera og mikrofon.",
    "This conversation has ended" : "Samtalen er slut",
    "Mute audio" : "Slå lyden fra",
    "Disable video" : "Deaktiver video",
    "Share screen" : "Del skærm",
    "Share whole screen" : "Del hele skærmen",
    "Share a single window" : "Del et vindue",
    "Show your screen" : "Vis din skærm",
    "Stop screensharing" : "Stop skærmdeling",
    "Mute audio (m)" : "Slå lyden fra (m)",
    "Unmute audio (m)" : "Slå lyden til (m)",
    "No audio" : "Ingen lyd",
    "Disable video (v)" : "Slå video fra (v)",
    "Enable video (v)" : "Slå video til (v)",
    "No Camera" : "Intet kamera",
    "Screensharing is not supported by your browser." : "Skærmdeling er ikke understøttet af din browser.",
    "Screensharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden bliver vist gennem HTTPS.",
    "Screensharing options" : "Skærmdeling indstillinger",
    "Sharing your screen only works with Firefox version 52 or newer." : "Skærmdeling virker kun med Firefox version 52 eller nyere.",
    "Screensharing extension is required to share your screen." : "En skærmdeling udvidelse er påkrævet for at dele din skærm.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Brug venligst en anden browser som Firefox og Chrome for at dele din skærm.",
    "An error occurred while starting screensharing." : "Der opstod en fejl da du prøvede at dele skærm.",
    "Enable screensharing" : "Slå skærmdeling til",
    "moderator" : "moderator",
    "Demote from moderator" : "Degrader fra moderator",
    "Promote to moderator" : "Forfrem til moderator",
    "Remove participant" : "Fjern deltager",
    "Add participant …" : "Tilføj deltager…",
    "Favorited" : "Tilføjet til favoritter",
    "Remove from favorites" : "Fjernet fra favoritter",
    "Add to favorites" : "Føj til favoritter",
    "Leave conversation" : "Forlad samtale",
    "Delete conversation" : "Slet samtale",
    "Your screen" : "Din skærm",
    "{participantName}'s screen" : "{participantName}s skærm",
    "Guest's screen" : "Gæsts skærm",
    "Close" : "Luk",
    "Show screen" : "Vis skærm",
    "Enable video" : "Slå video til",
    "Access to microphone & camera is only possible with HTTPS" : "Adgang til mikrofon og kamera er kun tilgængeligt over HTTPS",
    "Access to microphone & camera was denied" : "Ingen adgang til mikrofon og kamera",
    "WebRTC is not supported in your browser" : "WebRTC er ikke undertøttet i din browser",
    "Error while accessing microphone & camera" : "Der opstod en fejl da vi prøvede at få adgang til din mikrofon og kamera",
    "a conversation" : "en samtale",
    "(Duration %s)" : "(Varighed %s)",
    "You attended a call with {user1}" : "Du deltog i et opkald med {user1}",
    "_%n guest_::_%n guests_" : ["%n gæst","%n gæster"],
    "You attended a call with {user1} and {user2}" : "Du deltog i et opkald med {user1} og {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Du deltog i et opkald med {user1}, {user2} og {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Du deltog i et opkald med {user1}, {user2}, {user3} og {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du deltog i et opkald med {user1}, {user2}, {user3}, {user4} og {user5}",
    "_%n other_::_%n others_" : ["%n andre","%n andre"],
    "{actor} invited you to {call}" : "{actor} inviterede dig til {call}",
    "{actor} created the conversation" : "{actor} oprettede samtalen",
    "You created the conversation" : "Du oprettede samtalen",
    "{actor} started a call" : "{actor} startede et opkald",
    "You started a call" : "Du startede et opkald",
    "{actor} joined the call" : "{actor} deltog i opkaldet",
    "You joined the call" : "Du forbandt til opkaldet",
    "{actor} left the call" : "{actor} forlod opkaldet",
    "You left the call" : "Du forlod opkaldet",
    "{actor} allowed guests" : "{actor} tillod gæster",
    "You allowed guests" : "Du tillod gæster",
    "{actor} disallowed guests" : "{actor} forbød gæster",
    "You disallowed guests" : "Du forbød gæster",
    "{actor} set a password" : "{actor} indstillede en adgangskode",
    "You set a password" : "Du indstillede en adgangskode",
    "{actor} removed the password" : "{actor} fjernede adgangskoden",
    "You removed the password" : "Du fjernede adgangskoden",
    "{actor} added {user}" : "{actor} tilføjede {user}",
    "You joined the conversation" : "Du forbandt til samtalen",
    "{actor} joined the conversation" : "{actor} forbandt til samtalen",
    "You added {user}" : "Du tilføjede {user}",
    "{actor} added you" : "{actor} tilføjede dig",
    "You left the conversation" : "Du forlod samtalen",
    "{actor} left the conversation" : "{actor} forlod samtalen",
    "{actor} removed {user}" : "{actor} fjernede {user}",
    "You removed {user}" : "Du fjernede {user}",
    "{actor} removed you" : "{actor} fjernede dig",
    "{actor} promoted {user} to moderator" : "{actor} forfremmede {user} til moderator",
    "You promoted {user} to moderator" : "Du forfremmede {user} til moderator",
    "{actor} promoted you to moderator" : "{actor} forfremmede dig til moderator",
    "{actor} demoted {user} from moderator" : "{actor} degraderede {user} fra moderator",
    "You demoted {user} from moderator" : "Du degraderede {user} fra moderator",
    "{actor} demoted you from moderator" : "{actor} degraderede dig fra moderator",
    "{actor} shared a file which is no longer available" : "{actor} delte en fil, der ikke længere er tilgængelig",
    "You shared a file which is no longer available" : "Du delte en fil, der ikke længere er tilgængelig",
    "%s (guest)" : "%s (gæst)",
    "Call with {user1} and {user2} (Duration {duration})" : "Opkald med {user1} og {user2} (Varighed {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Opkald med {user1}, {user2} og {user3} (Varighed {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Opkald med {user1}, {user2}, {user3} og {user4} (Varighed {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Opkald med {user1}, {user2}, {user3}, {user4} og {user5} (Varighed {duration})",
    "Talk to %s" : "Tal med %s",
    "File is not shared, or shared but not with the user" : "Filen er ikke delt, eller den er delt men ikke med brugeren",
    "You were invited to a conversation." : "Du blev inviteret til en samtale.",
    "Conversation invitation" : "Invitation til samtale",
    "Click the button below to join." : "Tryk på knappen nedenfor for at deltage.",
    "Join »%s«" : "Deltag i »%s«",
    "{user} sent you a private message" : "{user} sendte dig en privat besked",
    "{user} sent a message in conversation {call}" : "{user} sendte en besked i samtalen {call}",
    "A deleted user sent a message in conversation {call}" : "En slettet bruger sendte en besked i samtalen {call}",
    "A guest sent a message in conversation {call}" : "En gæst sendte en besked i samtalen {call}",
    "{user} mentioned you in a private conversation" : "{user} omtalte dig i en privat samtale",
    "{user} mentioned you in conversation {call}" : "{user} omtalte dig i samtalen {call}",
    "A deleted user mentioned you in conversation {call}" : "En slettet bruger omtalte dig i samtalen {call}",
    "A guest mentioned you in conversation {call}" : "En gæst omtalte dig i samtalen {call}",
    "{user} invited you to a private conversation" : "{user} inviterede dig til en privat samtale",
    "{user} invited you to a group conversation: {call}" : "{user} inviterede dig til en gruppesamtale: {call}",
    "{user} wants to talk with you" : "{user} vil gerne snakke med dig",
    "A group call has started in {call}" : "Et gruppeopkald er startet i {call}",
    "TURN server URL" : "TURN server URL",
    "Validate SSL certificate" : "Godkend SSL certifikat",
    "STUN server URL" : "STUN server URL",
    "TURN server protocols" : "TURN server protokoller ",
    "UDP and TCP" : "UDP og TCP",
    "UDP only" : "kun UDP",
    "TCP only" : "kun TCP",
    "Saved" : "Gemt",
    "Shared secret" : "Delt hemmelighed",
    "STUN servers" : "STUN servere",
    "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN server bliver brugt til at bestemme den offentlige IP adresse for deltagerne bagved en router.",
    "The password is wrong. Try again." : "Passwordet er forkert. Prøv igen.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signaleringsserver kan eventuelt bruges i større installationer. Efterlad tom for at bruge intern signaleringsserver.",
    "TURN server" : "TURN server",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN serveren bliver brugt til at proxy trafikken fra deltagerne bagved en firewall.",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "Signaling server URL" : "Signalserver URL",
    "Delete server" : "Slet server",
    "Add new server" : "Tilføj ny server",
    "TURN server shared secret" : "TURN server delte hemmelighed",
    "Test server" : "Test server",
    "New public conversation" : "Ny offentlig samtale",
    "New group conversation" : "Ny gruppesamtale",
    "Always notify" : "Giv altid besked",
    "Notify on @-mention" : "Giv besked ved @-omtale",
    "Never notify" : "Giv aldrig besked",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Du var inviteret til et <strong>snakke</strong> rum eller fik et <strong>opkald</strong>",
    "_%n other guest_::_%n other guests_" : ["%n anden gæst","%n andre gæster"],
    ", " : ", ",
    "Join now" : "Deltag nu",
    "{user} sent a message in a conversation" : "{user} sendte en besked i en samtale",
    "A deleted user sent a message in a conversation" : "En slettet bruger sendte en besked i en samtale",
    "A guest sent a message in a conversation" : "En gæst sendte en besked i en samtale",
    "{user} mentioned you in a conversation" : "{user} omtalte dig i en samtale",
    "A deleted user mentioned you in a conversation" : "En slettet bruger omtalte dig i en samtale",
    "A guest mentioned you in a conversation" : "En gæst omtalte dig i en samtale",
    "%s invited you to a private conversation" : "%s inviterede dig til en privat samtale",
    "%s invited you to a group conversation: %s" : "%s inviterede dig til en gruppesamtale: %s",
    "%s invited you to a group conversation" : "%s inviterede dig til en gruppesamtale",
    "{user} invited you to a group conversation" : "{user} inviterede dig til en gruppesamtale",
    "A group call has started" : "Et gruppeopkald er startet",
    "This call is password-protected" : "Dette opkald er password beskyttet ",
    "Signaling server" : "Signalerer server"
},
"nplurals=2; plural=(n != 1);");
